import QtQuick 2.5
import QtQuick.Window 2.3
import QtQuick.Controls 2.2
import QtMultimedia 5.9

Window {

    property var qmlObject

    id:idRoot
    width: 400
    height: 300
    visible: false

    Rectangle{
        id: idResult
        anchors.fill: parent
        color: "#ff999999"
    }

    Column{
        id: idMsg
        width: parent.width
        spacing: 16
        visible: false

        Text{
            id: idMessage
            font.pixelSize: 16

        }

        Button{
            anchors.horizontalCenter: parent.horizontalCenter
            text: "Exit"
            onClicked: {
                Qt.quit()
            }
        }
    }

    Component.onCompleted: {

        var addr = qtc.getPath()

        if(addr ==="none"){

            idMessage.text = "Error: \n\nTo open a qml-file, you must specify it as a parameter on the command line (bind the qml extension to this loader)"
            idMsg.visible = true

        } else {

            addr = addr.replace(/\\/g, '/')
            idMessage.text = addr
            getRemoteContent(addr)
        }
        //idRoot.showFullScreen()
    }

    function getRemoteContent(url){

        try {

            qmlObject.destroy();

        } catch(e) {}

        var request = new XMLHttpRequest()
        request.open('GET', url)
        request.onreadystatechange = function () {

            if (request.readyState === XMLHttpRequest.DONE) {
                if (request.status && request.status === 200) {

                    var text = request.responseText
                    var isWindow = false
                    if(/Window\s*\{/.test(text)===true){
                        isWindow = true
                    }

                    try{

                        qmlObject.destroy()

                    }catch(e){}

                    try{

                        qmlObject = Qt.createQmlObject(text,idResult)
                        if(isWindow){
                            qtc.loadFile(url)
                        } else {
                            idRoot.visible = true
                        }

                    }catch(error){
                        idRoot.visible = true
                        var msg = "Error loading QML: \n\n"
                        for (var i = 0; i < error.qmlErrors.length; i++) {
                            msg += "lineNumber: " + error.qmlErrors[i].lineNumber + "\n"
                            msg += "columnNumber: " + error.qmlErrors[i].columnNumber + "\n"
                            msg += "fileName: " + url + "\n"
                            msg += "message: " + error.qmlErrors[i].message + "\n"
                        }
                        idMessage.text = msg
                        idMsg.visible = true
                    }
                }
            }
        }
        request.send()
    }

}
